##############################################
### fsQCA, Two-step 
### Preventive conflicts
###
##############################################
##
## Remote conditions: "State.extractivism", "Scarcity", "Tensions", "Marginalization"
## Proximate: "Internal.conflicts", "Coercion", "Cultural", "Participation", "Narratives", "INGOs" 
##
##########################

rm(list = ls())

library(QCA)
library(SetMethods)

setwd()

REC <- read.csv("Normalized scores_preventive.csv", row.names=1, sep=";")
REC
head(REC)

################################################################
##
## Check for skewedness
##
##########################################


xy.plot("Scarcity", "OUT1", REC, jitter=TRUE)
## 7 cases do not have it out of 23

xy.plot("Marginalization", "OUT1", REC, jitter=TRUE)
## 8/23 do not have it

xy.plot("Livelihoods", "OUT1", REC, jitter=TRUE)
## only 2 do not have it --> skewed

xy.plot("Tensions", "OUT1", REC, jitter=TRUE)
## 7/23 do not have it

xy.plot("State.extractivism", "OUT1", REC, jitter=TRUE)
## 5/23 do not have it --> slightly skewed

xy.plot("Internal.conflicts", "OUT1", REC, jitter=TRUE)
## no skewedness

xy.plot("Cultural", "OUT1", REC, jitter=TRUE)
## no skewedness

xy.plot("Narratives", "OUT1", REC, jitter=TRUE)
## 5 do not have it --> slightly skewed

xy.plot("Participation", "OUT1", REC, jitter=TRUE)
## 5 have it --> slightly skewed

xy.plot("Coercion", "OUT1", REC, jitter=TRUE)
## no skewedness

xy.plot("INGOs", "OUT1", REC, jitter=TRUE)
## 6 have it --> slightly skewed

###################################
##
## exclude conditions with less than 20% variance: livelihoods
##
###################################


##############################################
##############################################
##
## NECESSITY of remote conditions Y
##
#############################################


conds <- c("State.extractivism", "Scarcity", "Tensions", "Marginalization")

SUIN_y <- superSubset(data = REC,
                      outcome = "OUT1",
                      condition = conds,
                      incl.cut = 0.9,
                      cov.cut=0.6,
                      ron.cut = 0.5,
                      depth = 2,
                      show.cases= TRUE)

SUIN_y

##                                   inclN   RoN   covN  
##  ---------------------------------------------------- 
## 1  ~State.extractivism+Scarcity  0.901  0.545  0.665 
## 2  ~State.extractivism+Tensions  0.917  0.529  0.665 
##  ---------------------------------------------------- 


## both are barely within n.cut
## exclude as trivial 

#############################
#############################
##
## Sufficiency Y

conds1 <- c("Internal.conflicts", "Coercion", "Cultural", "Participation", "Narratives", "INGOs")

TT_1 <- truthTable(data = REC, 
                   outcome = "OUT1",
                   conditions = conds1,
                   incl.cut = 0.9,
                   show.cases = TRUE,
                   sort.by = c("OUT", "incl"))
TT_1

sol_1 <- minimize(TT_1,
                  show.cases = TRUE,
                  details=FALSE)
sol_1

## Model ambiguity

## M1: ~Internal.conflicts*Cultural*~Participation*Narratives*INGOs +
##     Internal.conflicts*Coercion*~Participation*Narratives*~INGOs +
##     Internal.conflicts*Cultural*~Participation*Narratives*~INGOs +
##     ~Internal.conflicts*Coercion*Cultural*~Participation*~Narratives*~INGOs +
##     (Internal.conflicts*Coercion*Cultural*~Participation*Narratives) -> OUT1 

## M2: ~Internal.conflicts*Cultural*~Participation*Narratives*INGOs +
##     Internal.conflicts*Coercion*~Participation*Narratives*~INGOs +
##     Internal.conflicts*Cultural*~Participation*Narratives*~INGOs +
##     ~Internal.conflicts*Coercion*Cultural*~Participation*~Narratives*~INGOs +
##     (Coercion*Cultural*~Participation*Narratives*INGOs) -> OUT1

sol_1p <- minimize(TT_1,
                   show.cases = TRUE,
                   include="?",
                   details=TRUE)
sol_1p

## M1: Coercion*~INGOs + Cultural*INGOs +  (Internal.conflicts*Cultural*~Participation) -> OUT1 
## M2: Coercion*~INGOs + Cultural*INGOs + (Internal.conflicts*Cultural*Narratives) -> OUT1 

pimplot(data = REC, 
        results = sol_1p, 
        outcome = "OUT1",
        jitter=TRUE,
        sol=2,
        all_labels= TRUE)

## one contradiction in kind: LAM1
## all cases explained

#############################
##
## NECESSITY of remote conditions ~Y
##
#############################

conds <- c("State.extractivism", "Scarcity", "Tensions", "Marginalization")

SUIN_ny <- superSubset(data = REC,
                      outcome = "~OUT1",
                      condition = conds,
                      incl.cut = 0.9,
                      cov.cut=0.6,
                      ron.cut = 0.5,
                      depth = 2,
                      show.cases= TRUE)

SUIN_ny

##                                 inclN   RoN   covN  
## ------------------------------------------------- 
##  1  Scarcity+~Marginalization  0.927  0.543  0.631 


## also barely over RoN cut! Exclude as trivial

############################################
##
## Sufficiency ~Y

TT_n1 <- truthTable(data = REC, 
                    outcome = "OUT1",
                    neg.out=TRUE,
                    conditions = conds1,
                    incl.cut = 0.9,
                    show.cases = TRUE,
                    sort.by = c("OUT", "incl"))
TT_n1

sol_n1 <- minimize(TT_n1,
                   show.cases = TRUE,
                   details=TRUE)
sol_n1

## M1: ~Internal.conflicts*~Coercion*~Cultural*~INGOs +
##     ~Internal.conflicts*~Coercion*Narratives*~INGOs +
##     ~Internal.conflicts*~Coercion*~Cultural*~Participation*Narratives +
##     Internal.conflicts*~Coercion*Participation*~Narratives*~INGOs +
##     ~Coercion*~Cultural*~Participation*Narratives*~INGOs +
##     Internal.conflicts*Coercion*~Cultural*~Participation*Narratives*INGOs
##  -> ~OUT1


sol_n1p <- minimize(TT_n1,
                    show.cases = TRUE,
                    include="?",
                    details=TRUE)
sol_n1p

## Model ambiguity

## shared terms: out2*cultural, cultural*INGOs

## M1: ~Coercion*~Cultural + ~Cultural*INGOs + (Participation + ~Internal.conflicts*~Coercion*~INGOs) -> ~OUT1 
## M2: ~Coercion*~Cultural + ~Cultural*INGOs + (Participation +                                               ~Internal.conflicts*Narratives*~INGOs) -> ~OUT1 
## M3: ~Coercion*~Cultural + ~Cultural*INGOs + (Internal.conflicts*~Narratives +                                             ~Internal.conflicts*~Coercion*~INGOs) -> ~OUT1 
## M4: ~Coercion*~Cultural + ~Cultural*INGOs + (Internal.conflicts*~Narratives +                                              ~Internal.conflicts*Narratives*~INGOs) -> ~OUT1 
## M5: ~Coercion*~Cultural + ~Cultural*INGOs + (~Coercion*~Narratives +                                            ~Internal.conflicts*~Coercion*~INGOs) -> ~OUT1 
## M6: ~Coercion*~Cultural + ~Cultural*INGOs + (~Coercion*~Narratives +                                  ~Internal.conflicts*Narratives*~INGOs) -> ~OUT1 also:


pimplot(data = REC, 
        results = sol_n1p, 
        outcome = "~OUT1",
        jitter=TRUE,
        sol=2,
        all_labels= TRUE)

## explains all
## no contradictions in kind
  
############################################################
############################################################
##
## Enhanced Standard Analysis Y
##
################################

## Simultaneous subset relations

SSR<-intersect(rownames(TT_1$tt)[TT_1$tt$OUT==1],rownames(TT_n1$tt)[TT_n1$tt$OUT==1])
SSR

## none

## Contradictory simplifying assumptions

CSA <- intersect(rownames(sol_n1p$SA$M1), rownames(sol_1p$SA$M1))
CSA

##  [1] "14" "16" "21" "23" "29" "30" "31" "32" "46" "48" "53" "55" "61" "62"
## [15] "63" "64"

TT_1esa <- esa(TT_1, contrad_rows = c("14", "16", "21", "23", "29", "30", "31", "32", "46", "48", "53", "55", "61", "62", "63", "64"))
TT_1esa

sol_1esa <- minimize(TT_1esa, details=TRUE)
sol_1esa

## model ambiguity still

## M1: ~Internal.conflicts*Cultural*~Participation*Narratives*INGOs +
##     Internal.conflicts*Coercion*~Participation*Narratives*~INGOs +
##     Internal.conflicts*Cultural*~Participation*Narratives*~INGOs +
##     ~Internal.conflicts*Coercion*Cultural*~Participation*~Narratives*~INGOs +
##     (Internal.conflicts*Coercion*Cultural*~Participation*Narratives) -> OUT1 

## M2: ~Internal.conflicts*Cultural*~Participation*Narratives*INGOs +
##     Internal.conflicts*Coercion*~Participation*Narratives*~INGOs +
##     Internal.conflicts*Cultural*~Participation*Narratives*~INGOs +
##     ~Internal.conflicts*Coercion*Cultural*~Participation*~Narratives*~INGOs +
##     (Coercion*Cultural*~Participation*Narratives*INGOs) -> OUT1 

sol_1esap <- minimize(TT_1esa, include="?", details=TRUE)
sol_1esap

## M1: Internal.conflicts*Cultural*~Participation +
##     Coercion*~Participation*~INGOs + Cultural*~Participation*INGOs -> OUT1

##                                                 inclS   PRI   covS   covU  
## ------------------------------------------------------------------------- 
##  1  Internal.conflicts*Cultural*~Participation  0.964  0.914  0.661  0.157 
##  2              Coercion*~Participation*~INGOs  0.918  0.865  0.463  0.091 
##  3               Cultural*~Participation*INGOs  1.000  1.000  0.306  0.124 
## ------------------------------------------------------------------------- 
##                                             M1  0.930  0.879  0.876 

pimplot(data = REC, 
        results = sol_1esap, 
        outcome = "OUT1",
        jitter=TRUE,
        all_labels= TRUE)

## explain all cases, no contradictions in kind

## INTERNAL.CONFLICTS*CULTURAL*participation: BAB1, JAS1, JAS2, RAS, KRO1
## COERCION*participation*ingos: ROM2, FAR, JAS1, JAS2, RAS
## CULTURAL*participation*INGOs: ROY, MCD, VEL, KRO1

###########################################################
##
## ESA ~Y
##
###################

TT_n1esa <- esa(TT_n1, contrad_rows = c("14", "16", "21", "23", "29", "30", "31", "32", "46", "48", "53", "55", "61", "62", "63", "64"))
TT_n1esa

sol_n1esa <- minimize(TT_n1esa, details=TRUE)
sol_n1esa

sol_n1esap <- minimize(TT_n1esa, include="?", details=TRUE)
sol_n1esap

## M1: ~COERCION*~Cultural + ~Cultural*INGOs + (~Internal.conflicts*~COERCION*~INGOs +
##     ~COERCION*Participation*~INGOs) -> ~OUT1 
## M2: ~COERCION*~Cultural + ~Cultural*INGOs + (~Internal.conflicts*~COERCION*~INGOs +
##     ~COERCION*~Narratives*~INGOs) -> ~OUT1 
## M3: ~COERCION*~Cultural + ~Cultural*INGOs + (~COERCION*Participation*~INGOs +
##     ~Internal.conflicts*~Participation*Narratives*~INGOs) -> ~OUT1 

pimplot(data = REC, 
          results = sol_n1esap, 
          outcome = "~OUT1",
          jitter=TRUE,
          sol=2,
          all_labels= TRUE)

## internal.conflicts*coercion: COL, URK-2, JAS3, FRA1, FRA2, ROM3, GED
## cultural*INGOS: REY, URK-2
## coercion*PARTICIPATION: REI, CON, FRA2, FRA1, JAS3
## coercion*narratives: FRA1, CON, REI


#############################################################
##
## ROBUSTNESS CHECK
##
#######################################

## create initial solution

IS <- sol_1esap

## Create Test solutions

## a) Altering consistency

TS1 <- minimize(data = REC,
                 outcome  = "OUT1",
                 conditions = conds1,
                 incl.cut = 0.75,
                 n.cut = 1,
                 include = "?",
                 details = TRUE, 
                 show.cases = TRUE)


TS1

## M1: Cultural + ~INGOs + (Internal.conflicts) <-> OUT1 
## M2: Cultural + ~INGOs + (Coercion) <-> OUT1

TS2 <- minimize(data = REC,
                 outcome  = "OUT1",
                 conditions = conds1,
                 incl.cut = 0.8,
                 n.cut = 1,
                 include = "?",
                 details = TRUE, 
                 show.cases = TRUE)


TS2

## M1: Cultural + (~Participation*~Narratives + Narratives*~INGOs) -> OUT1 
## M2: Cultural + (~Participation*~INGOs + Participation*Narratives) -> OUT1 
## M3: Cultural + (~Participation*~INGOs + Narratives*~INGOs) -> OUT1

######################################
## a) Altering n-cut

TS3 <- minimize(data = REC,
                 outcome  = "OUT1",
                 conditions = conds1,
                 incl.cut=0.9,
                 n.cut = 2,
                 include = "?",
                 details = TRUE, 
                 show.cases = TRUE)


TS3

## M1: Coercion => OUT1

#### Create test list in set

TS <- list(TS1, TS2, TS3)

###########################################
##
## Check robustness parameters
##
###################################

RF <- rob.fit(test_sol = TS, 
                      initial_sol = IS,  
                      outcome = "OUT1")
RF

##                  RF_cov RF_cons RF_SC
##   Robustness_Fit  0.783   0.986 0.667


rob.xyplot(test_sol = TS, 
                  initial_sol = IS, 
                  outcome = "OUT1", 
                  fontsize = 2.5,
                  jitter= TRUE)

## BAB1, ROY are part of IS but not TS
## REY, LAM1 are part of TS but not IS

rob.cases(test_sol = TS, 
                 initial_sol = IS, 
                 outcome = "OUT1")

## robust typical: 80% of cases with outcome; FAR, JAS1, JAS2, KRO1, MCD, RAS, ROM2, VEL
## shaky typical: 20%; ROY, BAB1
## robust deviant: 0
## shaky deviant: 0
## possible deviant: 7%, REY
## possible typicals: 0

#############################
#############################
##
## Robustness ~Y
##
###########################

ISn <- sol_n1esap

## Create test solution

## Alter consistency

TSn1 <- minimize(data = REC,
                  outcome  = "OUT1",
                  neg.out=TRUE,
                  conditions = conds1,
                  incl.cut = 0.75,
                  n.cut = 1,
                  include = "?",
                  details = TRUE, show.cases = TRUE)


TSn1


TSn2 <- minimize(data = REC,
                  outcome  = "OUT1",
                  neg.out=TRUE,
                  conditions = conds1,
                  incl.cut = 0.8,
                  n.cut = 1,
                  include = "?",
                  details = TRUE, show.cases = TRUE)
TSn2


######### Alter n cut


TSn3 <- minimize(data = REC,
                  outcome  = "OUT1",
                  neg.out=TRUE,
                  conditions = conds1,
                  incl.cut = 0.9,
                  n.cut = 2,
                  include = "?",
                  details = TRUE, show.cases = TRUE)
TSn3

## M1: ~coercion => out1 
## M2: ~internal.conflicts*~INGOs => out1 

#### Create test list

TSn <- list(TSn1, TSn2, TSn3)
TSn


########## Robustness fit

RF <- rob.fit(test_sol = TSn, 
                     initial_sol = ISn,  
                     outcome = "~OUT1")
RF

##                  RF_cov RF_cons RF_SC
##   Robustness_Fit  0.927   1.007 0.772

rob.xyplot(test_sol = TSn, 
                  initial_sol = ISn, 
                  outcome = "~OUT1",
                  fontsize = 2.5,
                  jitter= TRUE)

## 1 case is part of IS but not TS: REY

########## Case fit

rob.cases(test_sol = TSn, 
                 initial_sol = ISn, 
                 outcome = "~OUT1")

## robust typical: 84.62% 
##               COL, CON, FRA1, FRA2, GED, JAS3, URK-2, REI, ROM, PERE, VIL, TAR

## robust deviant: 0

## shaky typical cases: 7.69%  
##                 REY

## shaky deviant: 0
## possible typical: 0
## possible deviant: 1, BAB-1
## one extreme deviant coverage: LAM1

######################################################
##
## CLUSTER DIAGNOSTICS
##
######################################################
##
## Y

CS <- cluster(results = IS, 
              data = REC, 
              outcome  = "OUT1", 
              unit_id = "Country", 
              cluster_id = "Cluster.region", 
              wicons = FALSE)
CS

## consistency is good for all terms across regions, 0.952 or higher

## coverage:
## Internal.conflicts*Cultural*participation: low in Asia, ~0.6 NA, LatAm
## OUT2*participation*ingos: pretty low everywhere but Oce
## Cultural*participation*INGOs

## no clear distinction for geographic bias

######################################################
##
## ~Y

CSn <- cluster(results = ISn, 
               data = REC, 
               outcome  = "~OUT1", 
               sol=2,
               unit_id = "Country", 
               cluster_id = "Cluster.region", 
               wicons = FALSE)
CSn

## Consistency 0.942 or higher everywhere

## Coverage: 
## out2*narratives*ingos: 1 everywhere but CA (N/A)
## int.confl.*out2*ingos: higher than 0.9 everywhere, CA (N/A)
## out2*cultural: 1 everywhere but Asia, CA, Oce (N/A)
## cultural*INGOs: 1 everywhere but Asia, EU, Oce (N/A)